#
# spec file for package python-dictknife
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-dictknife
Version:        0.14.1
Release:        2.1
Summary:        Army knife of handling data
License:        MIT
URL:            https://github.com/podhmo/dictknife
Source:         https://github.com/podhmo/dictknife/archive/%{version}.tar.gz#/dictknife-%{version}.tar.gz
Patch0:         support-python-310.patch
BuildRequires:  %{python_module google-api-python-client}
BuildRequires:  %{python_module google-auth-oauthlib}
BuildRequires:  %{python_module jsonpatch}
BuildRequires:  %{python_module magicalimport}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module prestring}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module ruamel.yaml}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
Suggests:       python-ruamel.yaml
Suggests:       python-google-api-python-client
Suggests:       python-google-auth-oauthlib
Suggests:       python-jsonpatch
Suggests:       python-magicalimport
Suggests:       python-prestring
BuildArch:      noarch
%python_subpackages

%description
Army knife of handling data, able to read and write JSON, YAML and TOML,
and transform, merge and diff datasets.

Includes jsonknife for splitting files and dereferencing JSON using
JSON pointer syntax.

%prep
%autosetup -p1 -n dictknife-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/dictknife
%python_clone -a %{buildroot}%{_bindir}/jsonknife
%python_clone -a %{buildroot}%{_bindir}/swaggerknife
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative dictknife
%python_install_alternative jsonknife
%python_install_alternative swaggerknife

%postun
%python_uninstall_alternative dictknife
%python_uninstall_alternative jsonknife
%python_uninstall_alternative swaggerknife

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/dictknife
%python_alternative %{_bindir}/jsonknife
%python_alternative %{_bindir}/swaggerknife
%{python_sitelib}/dictknife
%{python_sitelib}/dictknife-%{version}*-info

%changelog
* Thu Jun  5 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
* Mon Mar 18 2024 Dirk Müller <dmueller@suse.com>
- update to 0.14.1:
  * fix bug `unexpected keyword argument loader` is occured when
    yaml library is not installed
* Sat Dec  2 2023 Dirk Müller <dmueller@suse.com>
- update to 0.14.0:
  * use tomlkit instead of qtoml
  * use ruamel.yaml instead of pyyaml (for preserving comments)
  * add `dictknife diff -o pair`
* Thu Apr 14 2022 Ben Greiner <code@bnavigator.de>
- Update optional runtime and buildtime requirements
  * 0.13 replaced deprecated ouauth2client with newer oauthlib.
  * 0.11 replaced toml with qtoml (unavailabe in TW)
* Thu Feb  3 2022 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-python-310.patch:
  * Support Python 3.10.
* Mon Dec 13 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Drop python 3.6 support since python-google-api-python-client
  dropped it
* Mon Aug 17 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix source url to match up the reality as this was fetched from
  github
* Wed Aug 12 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v0.13.0
* Fri Jul 12 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.10.3
